#pragma once

// MassBuilderSaveTool
// Copyright (C) 2021-2022 Guillaume Jacquemin
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#include <Corrade/Containers/Array.h>
#include <Corrade/Containers/StaticArray.h>

#include <Magnum/Types.h>

#include "Decal.h"
#include "Accessory.h"

using namespace Corrade;
using namespace Magnum;

enum class ArmourSlot {
    Face            = 0,
    UpperHead       = 1,
    LowerHead       = 2,
    Neck            = 3,
    UpperBody       = 4,
    MiddleBody      = 5,
    LowerBody       = 6,
    FrontWaist      = 7,
    LeftFrontSkirt  = 8,
    RightFrontSkirt = 9,
    LeftSideSkirt   = 10,
    RightSideSkirt  = 11,
    LeftBackSkirt   = 12,
    RightBackSkirt  = 13,
    BackWaist       = 14,
    LeftShoulder    = 15,
    RightShoulder   = 16,
    LeftUpperArm    = 17,
    RightUpperArm   = 18,
    LeftElbow       = 19,
    RightElbow      = 20,
    LeftLowerArm    = 21,
    RightLowerArm   = 22,
    Backpack        = 23,
    LeftHand        = 24,
    RightHand       = 25,
    LeftUpperLeg    = 26,
    RightUpperLeg   = 27,
    LeftKnee        = 28,
    RightKnee       = 29,
    LeftLowerLeg    = 30,
    RightLowerLeg   = 31,
    LeftAnkle       = 32,
    RightAnkle      = 33,
    LeftHeel        = 34,
    RightHeel       = 35,
    LeftFoot        = 36,
    RightFoot       = 37,
};

struct ArmourPart {
    ArmourSlot slot = ArmourSlot::Face;
    Int id = 0;
    Containers::StaticArray<4, Int> styles{ValueInit};
    Containers::Array<Decal> decals;
    Containers::Array<Accessory> accessories;
};
